@@ -58,6 +58,7 @@ void ClipPlaneSet::renderBegin(RenderContext* renderContext)
 
 void ClipPlaneSet::drawPrimitive(RenderContext* renderContext, int index)
 {
+#ifndef RGL_NO_OPENGL   
   GLdouble eqn[4];
   eqn[0] = normal.getRecycled(index).x;
   eqn[1] = normal.getRecycled(index).y;
@@ -65,19 +66,22 @@ void ClipPlaneSet::drawPrimitive(RenderContext* renderContext, int index)
   eqn[3] = offset.getRecycled(index);
   glClipPlane(firstPlane + index, eqn);
   glEnable(firstPlane + index);
+#endif
 }
 
 void ClipPlaneSet::enable(bool show)
 {
+#ifndef RGL_NO_OPENGL  
   for (int i=0; i<nPlanes; i++) {
     if (show) glEnable(firstPlane + i);
     else      glDisable(firstPlane + i);
   }
+#endif
 }
 
 void ClipPlaneSet::intersectBBox(AABox& bbox)
 {
-  GLdouble a, b, c, d, a1, b1, c1, d1;
+  GLfloat a, b, c, d, a1, b1, c1, d1;
   for (int j=0; j<3; j++) /* repeat to propagate changes between coordinates */
   for (int i=0; i<nPlanes; i++) {
     a = normal.getRecycled(i).x;
