@@ -20,6 +20,7 @@ void FPS::init(double time)
 
 void FPS::render(double t, RenderContext* ctx)
 {
+#ifndef RGL_NO_OPENGL
   if (lastTime + 1.0f < t ) {
     lastTime = t;
     sprintf(buffer, "FPS %d", framecnt);
@@ -36,7 +37,8 @@ void FPS::render(double t, RenderContext* ctx)
   glRasterPos2f( 1.0f, -0.9f);
 
   if (ctx->font)
-    ctx->font->draw(buffer, strlen(buffer), -1, 0.0, 0, *ctx);
+    ctx->font->draw(buffer, static_cast<int>(strlen(buffer)), -1, 0.0, 0, *ctx);
 
   framecnt++;
+#endif
 }
